==> sphere_connector-0.4.30.tar.gz: sphere_connector-0.4.30/sphere_connector/plotting.py <==
"""
The MIT License (MIT)
Copyright (c) 2014-2015 University of Bristol

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
OR OTHER DEALINGS IN THE SOFTWARE.
"""
import matplotlib
matplotlib.use("Agg")
import matplotlib.pyplot as plt
# from mpl_toolkits.mplot3d import axes3d
plt.style.use('ggplot')
import numpy as np
from StringIO import StringIO
import logging


class Plotter(object):
    def __init__(self, experiment):
        """
        Initialise the plotter
        :param experiment: The aggregtor
        :return: None
        """
        self.experiment = experiment

    def plot_sensors(self, ax, sensor_data, add_empty_row=False):
        """
        Plot the sensor data
        :param ax: The axis to plot on
        :param sensor_data: The sensor data
        :param add_empty_row: Whether to add an empty row
        :return: The figure
        """
        sensor_data = list(sensor_data)
        if add_empty_row:
            index = sensor_data[0][2].index
            sensor_data = [('N/A', None, None)] + sensor_data

        # for ax, sensor in zip(axes.flat, sorted( test_sensors ) ):
        for i, (sensor, uid, series) in enumerate(sensor_data):
            if sensor == 'N/A':
                # Add empty row
                ax.plot(index, np.zeros(shape=index.shape), label=sensor)
            else:
                ax.plot(series.index, series + i, label=uid)

        # print(test_sensors)
        ax.set_ylim([0, len(sensor_data)])
        ax.set_yticklabels(s[1] for s in sensor_data)
        ax.set_yticks(np.arange(len(sensor_data)) + 0.5)

    @staticmethod
    def plot_annotations(ax, dft, all_labels, alpha):
        """
        Plot annotations
        :param ax: Axis for plotting
        :param dft: Data frame
        :param all_labels: Labels
        :param alpha: Alpha for overlay plotting
        :return: None
        """
        ax.fill_between(dft.index, np.array(dft) + 1, np.array(dft) + 2,
                        facecolor='green', interpolate=True, alpha=alpha)
        ax.set_ylim([0, len(all_labels)])
        ax.set_yticklabels(all_labels)
        ax.set_yticks(np.arange(len(all_labels)) + 0.5)

    def plot_motion(self, show=False, save=True):
        """
        Plot motion sensors only
        :param show: Show the plot
        :param save: Save the plot
        :return: The figure
        """
        sensor_data = self.experiment.get_motion_data()
        fig, ax = plt.subplots(1, 1, figsize=(20, 10))
        self.plot_sensors(ax, sensor_data, False)

        if show:
            plt.show()
        if save:
            plt.savefig(self.experiment.file_stub + '_motion.pdf')
        return fig

    def plot_environmental(self, include_motion=False, show=False, save=True):
        """
        Plot environmental sensors
        :param include_motion: Whether to include motion sensors
        :param show: Show the plot
        :param save: Save the plot
        :return: The figure
        """
        fig, ax = plt.subplots(1, 1, figsize=(20, 20))
        self.plot_sensors(ax, self.experiment.get_environmental_data(include_motion), False)

        if show:
            plt.show()
        if save:
            plt.savefig(self.experiment.file_stub + '_env.pdf')
        return fig

    def plot_motion_with_annotations(self, annotator, tier, show=False, save=True):
        """
        Plot motion sensors with annotations below (for generic tiers)
        :param annotator: Annotator
        :param tier: Annotation tier
        :param show: Show the plot
        :param save: Save the plot
        :return: The figure
        """
        dft, all_labels = self.experiment.get_annotations(annotator, tier)

        if tier == "Location":
            fig, ax = plt.subplots(1, 1, figsize=(20, 10))
            ax2 = ax.twinx()
            add_empty_row = True
            alpha = 0.2
        else:
            fig, axes = plt.subplots(2, 1, figsize=(20, 20))
            ax = axes.flat[0]
            ax2 = axes.flat[1]
            add_empty_row = False
            alpha = 1.0

        self.plot_sensors(ax, self.experiment.get_motion_data(), add_empty_row)
        self.plot_annotations(ax2, dft, all_labels, alpha)

        if show:
            plt.show()
        if save:
            plt.savefig(self.experiment.file_stub + '_rooms.pdf')
        return fig

    def plot_video(self, show=False, save=True):
        """
        Plot video data
        :param show: Show the plot
        :param save: Save the plot
        :return: The figure
        """
        n = len(self.experiment.video.sensors)
        fig = plt.figure(figsize=(20, 10 * n))
        for i, (sensor, uid, dat) in self.experiment.get_video_data():
            ax = fig.add_subplot(n, 1, i, projection='3d')
            sensor_ids = []
            try:
                ax.scatter(dat[:, 0], dat[:, 1], dat[:, 2])
                sensor_ids.append(uid)
                ax.set_legend(sensor_ids, loc=0)
                ax.set_title(sensor)
            except Exception as e:
                logging.debug(sensor, uid, e)
                return None
        if show:
            plt.show()
        if save:
            plt.savefig(self.experiment.file_stub + '_video.pdf')
        return fig

    def plot_wearable(self, show=False, save=True):
        """
        Plot wearable data
        :param show: Show the plot
        :param save: Save the plot
        :return: The figure
        """
        n = len(self.experiment.video.sensors)
        fig = plt.figure(figsize=(20, 10 * n))
        for i, (sensor, uid, dat) in self.experiment.get_wearable_data():
            ax = fig.add_subplot(n, 1, i, projection='3d')
            sensor_ids = []
            try:
                ax.scatter(dat[:, 0], dat[:, 1], dat[:, 2])
                sensor_ids.append(uid)
                ax.set_legend(sensor_ids, loc=0)
                ax.set_title(sensor)
            except Exception as e:
                logging.debug(sensor, uid, e)
                return None
        if show:
            plt.show()
        if save:
            plt.savefig(self.experiment.file_stub + '_wearable.pdf')
        return fig


def img_from_fig(fig):
    """
    Produce image from figure
    :param fig: The figure
    :return: The image
    """
    if not fig:
        return img_from_fig(get_test_figure())
    img = StringIO()
    fig.savefig(img)
    img.seek(0)
    return img


def get_test_figure():
    """
    Gets a simple test figure
    :return: The figure
    """
    fig, ax = plt.subplots(1, 1, figsize=(20, 10))
    t = np.arange(0.0, 2.0, 0.01)
    s = np.sin(2 * np.pi * t)
    ax.plot(t, s)
    ax.set_xlabel('time (s)')
    ax.set_ylabel('voltage (mV)')
    ax.set_title('About as simple as it gets, folks')
    return fig

==> sphere_connector-0.5.4.tar.gz: sphere_connector-0.5.4/sphere_connector/plotting.py <==
"""
The MIT License (MIT)
Copyright (c) 2014-2015 University of Bristol

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
OR OTHER DEALINGS IN THE SOFTWARE.
"""
import matplotlib
matplotlib.use("Agg")
import matplotlib.pyplot as plt
# from mpl_toolkits.mplot3d import axes3d
plt.style.use('ggplot')
import numpy as np
from StringIO import StringIO
import logging


class Plotter(object):
    def __init__(self, experiment):
        """
        Initialise the plotter
        :param experiment: The aggregtor
        :return: None
        """
        self.experiment = experiment

    def plot_sensors(self, ax, sensor_data, add_empty_row=False):
        """
        Plot the sensor data
        :param ax: The axis to plot on
        :param sensor_data: The sensor data
        :param add_empty_row: Whether to add an empty row
        :return: The figure
        """
        sensor_data = list(sensor_data)
        if add_empty_row:
            index = sensor_data[0][2].index
            sensor_data = [('N/A', None, None)] + sensor_data

        # for ax, sensor in zip(axes.flat, sorted( test_sensors ) ):
        for i, (sensor, uid, series) in enumerate(sensor_data):
            if sensor == 'N/A':
                # Add empty row
                ax.plot(index, np.zeros(shape=index.shape), label=sensor)
            else:
                ax.plot(series.index, series + i, label=uid)

        # print(test_sensors)
        ax.set_ylim([0, len(sensor_data)])
        ax.set_yticklabels(s[1] for s in sensor_data)
        ax.set_yticks(np.arange(len(sensor_data)) + 0.5)

    @staticmethod
    def plot_annotations(ax, dft, all_labels, alpha):
        """
        Plot annotations
        :param ax: Axis for plotting
        :param dft: Data frame
        :param all_labels: Labels
        :param alpha: Alpha for overlay plotting
        :return: None
        """
        ax.fill_between(dft.index, np.array(dft) + 1, np.array(dft) + 2,
                        facecolor='green', interpolate=True, alpha=alpha)
        ax.set_ylim([0, len(all_labels)])
        ax.set_yticklabels(all_labels)
        ax.set_yticks(np.arange(len(all_labels)) + 0.5)

    def plot_motion(self, show=False, save=True):
        """
        Plot motion sensors only
        :param show: Show the plot
        :param save: Save the plot
        :return: The figure
        """
        sensor_data = self.experiment.get_motion_data()
        fig, ax = plt.subplots(1, 1, figsize=(20, 10))
        self.plot_sensors(ax, sensor_data, False)

        if show:
            plt.show()
        if save:
            plt.savefig(self.experiment.file_stub + '_motion.pdf')
        return fig

    def plot_environmental(self, include_motion=False, show=False, save=True):
        """
        Plot environmental sensors
        :param include_motion: Whether to include motion sensors
        :param show: Show the plot
        :param save: Save the plot
        :return: The figure
        """
        fig, ax = plt.subplots(1, 1, figsize=(20, 20))
        self.plot_sensors(ax, self.experiment.get_environmental_data(include_motion), False)

        if show:
            plt.show()
        if save:
            plt.savefig(self.experiment.file_stub + '_env.pdf')
        return fig

    def plot_motion_with_annotations(self, annotator, tier, show=False, save=True):
        """
        Plot motion sensors with annotations below (for generic tiers)
        :param annotator: Annotator
        :param tier: Annotation tier
        :param show: Show the plot
        :param save: Save the plot
        :return: The figure
        """
        dft, all_labels = self.experiment.get_annotations(annotator, tier)

        if tier == "Location":
            fig, ax = plt.subplots(1, 1, figsize=(20, 10))
            ax2 = ax.twinx()
            add_empty_row = True
            alpha = 0.2
        else:
            fig, axes = plt.subplots(2, 1, figsize=(20, 20))
            ax = axes.flat[0]
            ax2 = axes.flat[1]
            add_empty_row = False
            alpha = 1.0

        resample = {'rule': 'S', 'fill_method': 'ffill', 'how': 'max'}
        self.plot_sensors(ax, self.experiment.get_motion_data(resample=resample), add_empty_row)
        self.plot_annotations(ax2, dft, all_labels, alpha)

        if show:
            plt.show()
        if save:
            plt.savefig(self.experiment.file_stub + '_rooms.pdf')
        return fig

    def plot_video(self, show=False, save=True):
        """
        Plot video data
        :param show: Show the plot
        :param save: Save the plot
        :return: The figure
        """
        n = len(self.experiment.video.sensors)
        fig = plt.figure(figsize=(20, 10 * n))
        for i, (sensor, uid, dat) in self.experiment.get_video_data():
            ax = fig.add_subplot(n, 1, i, projection='3d')
            sensor_ids = []
            try:
                ax.scatter(dat[:, 0], dat[:, 1], dat[:, 2])
                sensor_ids.append(uid)
                ax.set_legend(sensor_ids, loc=0)
                ax.set_title(sensor)
            except Exception as e:
                logging.debug(sensor, uid, e)
                return None
        if show:
            plt.show()
        if save:
            plt.savefig(self.experiment.file_stub + '_video.pdf')
        return fig

    def plot_wearable(self, show=False, save=True):
        """
        Plot wearable data
        :param show: Show the plot
        :param save: Save the plot
        :return: The figure
        """
        n = len(self.experiment.video.sensors)
        fig = plt.figure(figsize=(20, 10 * n))
        for i, (sensor, uid, dat) in self.experiment.get_wearable_data():
            ax = fig.add_subplot(n, 1, i, projection='3d')
            sensor_ids = []
            try:
                ax.scatter(dat[:, 0], dat[:, 1], dat[:, 2])
                sensor_ids.append(uid)
                ax.set_legend(sensor_ids, loc=0)
                ax.set_title(sensor)
            except Exception as e:
                logging.debug(sensor, uid, e)
                return None
        if show:
            plt.show()
        if save:
            plt.savefig(self.experiment.file_stub + '_wearable.pdf')
        return fig


def img_from_fig(fig):
    """
    Produce image from figure
    :param fig: The figure
    :return: The image
    """
    if not fig:
        return img_from_fig(get_test_figure())
    img = StringIO()
    fig.savefig(img)
    img.seek(0)
    return img


def get_test_figure():
    """
    Gets a simple test figure
    :return: The figure
    """
    fig, ax = plt.subplots(1, 1, figsize=(20, 10))
    t = np.arange(0.0, 2.0, 0.01)
    s = np.sin(2 * np.pi * t)
    ax.plot(t, s)
    ax.set_xlabel('time (s)')
    ax.set_ylabel('voltage (mV)')
    ax.set_title('About as simple as it gets, folks')
    return fig
